@@ -25,6 +25,10 @@ Medical Language System
 
 =head2 Optional Arguments:
 
+=head3 --debug
+
+Sets the debug flag for testing
+
 =head3 --username STRING
 
 Username is required to access the umls database on MySql
@@ -142,7 +146,7 @@ this program; if not, write to:
 use UMLS::Interface;
 use Getopt::Long;
 
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui", "forcerun", "verbose", "cuilist=s", "realtime");
+GetOptions( "version", "help", "debug", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "cui", "forcerun", "verbose", "cuilist=s", "realtime");
 
 
 #  if help is defined, print out help
@@ -177,6 +181,10 @@ my $umls = "";
 
 my %option_hash = ();
 
+
+if(defined $opt_debug) {
+    $option_hash{"debug"} = $opt_debug;
+}
 if(defined $opt_realtime) {
     $option_hash{"realtime"} = $opt_realtime;
 }
@@ -325,6 +333,8 @@ sub showHelp() {
 
     print "Options:\n\n";
 
+    print "--debug                  Sets the debug flag for testing.\n\n";
+
     print "--username STRING        Username required to access mysql\n\n";
 
     print "--password STRING        Password required to access mysql\n\n";
@@ -363,7 +373,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findLeastCommonSubsumer.pl,v 1.7 2010/01/07 23:15:44 btmcinnes Exp $';
+    print '$Id: findLeastCommonSubsumer.pl,v 1.8 2010/01/20 16:28:31 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
